# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/credit_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/credit_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import credit_pb2 as eolymp_dot_community_dot_credit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/community/credit_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/community/credit.proto\x1a!eolymp/wellknown/expression.proto\"=\n\x11\x43reateCreditInput\x12(\n\x06\x63redit\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Credit\"\'\n\x12\x43reateCreditOutput\x12\x11\n\tcredit_id\x18\x01 \x01(\t\"&\n\x11\x44\x65leteCreditInput\x12\x11\n\tcredit_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteCreditOutput\"\xeb\x02\n\x10ListCreditsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.community.ListCreditsInput.Filter\x1a\xfc\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\treference\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04note\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12/\n\x06\x61mount\x18\x04 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x30\n\x06\x61\x63tive\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"K\n\x11ListCreditsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.community.Credit\"D\n\x11RedeemCreditInput\x12\x0e\n\x06\x61mount\x18\x01 \x01(\r\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0c\n\x04note\x18\x03 \x01(\t\"\x14\n\x12RedeemCreditOutput\"\x1c\n\x1a\x44\x65scribeCreditBalanceInput\".\n\x1b\x44\x65scribeCreditBalanceOutput\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\r2\xc1\x06\n\rCreditService\x12\x98\x01\n\x0c\x43reateCredit\x12#.eolymp.community.CreateCreditInput\x1a$.eolymp.community.CreateCreditOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:credit:write\x82\xd3\xe4\x93\x02\n\"\x08/credits\x12\xa4\x01\n\x0c\x44\x65leteCredit\x12#.eolymp.community.DeleteCreditInput\x1a$.eolymp.community.DeleteCreditOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:credit:write\x82\xd3\xe4\x93\x02\x16*\x14/credits/{credit_id}\x12\x94\x01\n\x0bListCredits\x12\".eolymp.community.ListCreditsInput\x1a#.eolymp.community.ListCreditsOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:credit:read\x82\xd3\xe4\x93\x02\n\x12\x08/credits\x12\x9f\x01\n\x0cRedeemCredit\x12#.eolymp.community.RedeemCreditInput\x1a$.eolymp.community.RedeemCreditOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:credit:write\x82\xd3\xe4\x93\x02\x11\"\x0f/credits:redeem\x12\xb4\x01\n\x0f\x44\x65scribeBalance\x12,.eolymp.community.DescribeCreditBalanceInput\x1a-.eolymp.community.DescribeCreditBalanceOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:credit:read\x82\xd3\xe4\x93\x02\x12\x12\x10/credits:balanceB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.credit_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_CREDITSERVICE'].methods_by_name['CreateCredit']._loaded_options = None
  _globals['_CREDITSERVICE'].methods_by_name['CreateCredit']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\032\212\343\n\026community:credit:write\202\323\344\223\002\n\"\010/credits'
  _globals['_CREDITSERVICE'].methods_by_name['DeleteCredit']._loaded_options = None
  _globals['_CREDITSERVICE'].methods_by_name['DeleteCredit']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\032\212\343\n\026community:credit:write\202\323\344\223\002\026*\024/credits/{credit_id}'
  _globals['_CREDITSERVICE'].methods_by_name['ListCredits']._loaded_options = None
  _globals['_CREDITSERVICE'].methods_by_name['ListCredits']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\031\212\343\n\025community:credit:read\202\323\344\223\002\n\022\010/credits'
  _globals['_CREDITSERVICE'].methods_by_name['RedeemCredit']._loaded_options = None
  _globals['_CREDITSERVICE'].methods_by_name['RedeemCredit']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\032\212\343\n\026community:credit:write\202\323\344\223\002\021\"\017/credits:redeem'
  _globals['_CREDITSERVICE'].methods_by_name['DescribeBalance']._loaded_options = None
  _globals['_CREDITSERVICE'].methods_by_name['DescribeBalance']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\031\212\343\n\025community:credit:read\202\323\344\223\002\022\022\020/credits:balance'
  _globals['_CREATECREDITINPUT']._serialized_start=224
  _globals['_CREATECREDITINPUT']._serialized_end=285
  _globals['_CREATECREDITOUTPUT']._serialized_start=287
  _globals['_CREATECREDITOUTPUT']._serialized_end=326
  _globals['_DELETECREDITINPUT']._serialized_start=328
  _globals['_DELETECREDITINPUT']._serialized_end=366
  _globals['_DELETECREDITOUTPUT']._serialized_start=368
  _globals['_DELETECREDITOUTPUT']._serialized_end=388
  _globals['_LISTCREDITSINPUT']._serialized_start=391
  _globals['_LISTCREDITSINPUT']._serialized_end=754
  _globals['_LISTCREDITSINPUT_FILTER']._serialized_start=502
  _globals['_LISTCREDITSINPUT_FILTER']._serialized_end=754
  _globals['_LISTCREDITSOUTPUT']._serialized_start=756
  _globals['_LISTCREDITSOUTPUT']._serialized_end=831
  _globals['_REDEEMCREDITINPUT']._serialized_start=833
  _globals['_REDEEMCREDITINPUT']._serialized_end=901
  _globals['_REDEEMCREDITOUTPUT']._serialized_start=903
  _globals['_REDEEMCREDITOUTPUT']._serialized_end=923
  _globals['_DESCRIBECREDITBALANCEINPUT']._serialized_start=925
  _globals['_DESCRIBECREDITBALANCEINPUT']._serialized_end=953
  _globals['_DESCRIBECREDITBALANCEOUTPUT']._serialized_start=955
  _globals['_DESCRIBECREDITBALANCEOUTPUT']._serialized_end=1001
  _globals['_CREDITSERVICE']._serialized_start=1004
  _globals['_CREDITSERVICE']._serialized_end=1837
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.executor import evaluation_task_pb2 as _evaluation_task_pb2
from eolymp.executor import generation_task_pb2 as _generation_task_pb2
from eolymp.executor import stress_task_pb2 as _stress_task_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateTaskInput(_message.Message):
    __slots__ = ("evaluation", "generation", "stress")
    EVALUATION_FIELD_NUMBER: _ClassVar[int]
    GENERATION_FIELD_NUMBER: _ClassVar[int]
    STRESS_FIELD_NUMBER: _ClassVar[int]
    evaluation: _evaluation_task_pb2.EvaluationTask
    generation: _generation_task_pb2.GenerationTask
    stress: _stress_task_pb2.StressTask
    def __init__(self, evaluation: _Optional[_Union[_evaluation_task_pb2.EvaluationTask, _Mapping]] = ..., generation: _Optional[_Union[_generation_task_pb2.GenerationTask, _Mapping]] = ..., stress: _Optional[_Union[_stress_task_pb2.StressTask, _Mapping]] = ...) -> None: ...

class CreateTaskOutput(_message.Message):
    __slots__ = ("task_id",)
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    task_id: str
    def __init__(self, task_id: _Optional[str] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.rating import rating_pb2 as _rating_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetRatingInput(_message.Message):
    __slots__ = ("rating",)
    RATING_FIELD_NUMBER: _ClassVar[int]
    rating: _rating_pb2.Rating
    def __init__(self, rating: _Optional[_Union[_rating_pb2.Rating, _Mapping]] = ...) -> None: ...

class SetRatingOutput(_message.Message):
    __slots__ = ("rating_id",)
    RATING_ID_FIELD_NUMBER: _ClassVar[int]
    rating_id: str
    def __init__(self, rating_id: _Optional[str] = ...) -> None: ...

class UpdateRatingInput(_message.Message):
    __slots__ = ("rating_id", "rating")
    RATING_ID_FIELD_NUMBER: _ClassVar[int]
    RATING_FIELD_NUMBER: _ClassVar[int]
    rating_id: str
    rating: _rating_pb2.Rating
    def __init__(self, rating_id: _Optional[str] = ..., rating: _Optional[_Union[_rating_pb2.Rating, _Mapping]] = ...) -> None: ...

class UpdateRatingOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteRatingInput(_message.Message):
    __slots__ = ("rating_id", "rating")
    RATING_ID_FIELD_NUMBER: _ClassVar[int]
    RATING_FIELD_NUMBER: _ClassVar[int]
    rating_id: str
    rating: _rating_pb2.Rating
    def __init__(self, rating_id: _Optional[str] = ..., rating: _Optional[_Union[_rating_pb2.Rating, _Mapping]] = ...) -> None: ...

class DeleteRatingOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeRatingInput(_message.Message):
    __slots__ = ("rating_id",)
    RATING_ID_FIELD_NUMBER: _ClassVar[int]
    rating_id: str
    def __init__(self, rating_id: _Optional[str] = ...) -> None: ...

class DescribeRatingOutput(_message.Message):
    __slots__ = ("rating",)
    RATING_FIELD_NUMBER: _ClassVar[int]
    rating: _rating_pb2.Rating
    def __init__(self, rating: _Optional[_Union[_rating_pb2.Rating, _Mapping]] = ...) -> None: ...

class ListRatingInput(_message.Message):
    __slots__ = ("member_id", "offset", "size", "after", "filters", "sort", "order")
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        TIMESTAMP: _ClassVar[ListRatingInput.Sortable]
    TIMESTAMP: ListRatingInput.Sortable
    class Filter(_message.Message):
        __slots__ = ("id", "contest_id", "timestamp")
        ID_FIELD_NUMBER: _ClassVar[int]
        CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        contest_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        timestamp: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionTimestamp]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., contest_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., timestamp: _Optional[_Iterable[_Union[_expression_pb2.ExpressionTimestamp, _Mapping]]] = ...) -> None: ...
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    member_id: str
    offset: int
    size: int
    after: str
    filters: ListRatingInput.Filter
    sort: ListRatingInput.Sortable
    order: _direction_pb2.Direction
    def __init__(self, member_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., after: _Optional[str] = ..., filters: _Optional[_Union[ListRatingInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListRatingInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ...) -> None: ...

class ListRatingOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_rating_pb2.Rating]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_rating_pb2.Rating, _Mapping]]] = ...) -> None: ...

class DescribeRatingBoundariesInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeRatingBoundariesOutput(_message.Message):
    __slots__ = ("levels",)
    class Level(_message.Message):
        __slots__ = ("id", "rating", "count")
        ID_FIELD_NUMBER: _ClassVar[int]
        RATING_FIELD_NUMBER: _ClassVar[int]
        COUNT_FIELD_NUMBER: _ClassVar[int]
        id: int
        rating: int
        count: int
        def __init__(self, id: _Optional[int] = ..., rating: _Optional[int] = ..., count: _Optional[int] = ...) -> None: ...
    LEVELS_FIELD_NUMBER: _ClassVar[int]
    levels: _containers.RepeatedCompositeFieldContainer[DescribeRatingBoundariesOutput.Level]
    def __init__(self, levels: _Optional[_Iterable[_Union[DescribeRatingBoundariesOutput.Level, _Mapping]]] = ...) -> None: ...

class DescribeRatingDistributionInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeRatingDistributionOutput(_message.Message):
    __slots__ = ("buckets",)
    class Bucket(_message.Message):
        __slots__ = ("min_rating", "max_rating", "count")
        MIN_RATING_FIELD_NUMBER: _ClassVar[int]
        MAX_RATING_FIELD_NUMBER: _ClassVar[int]
        COUNT_FIELD_NUMBER: _ClassVar[int]
        min_rating: int
        max_rating: int
        count: int
        def __init__(self, min_rating: _Optional[int] = ..., max_rating: _Optional[int] = ..., count: _Optional[int] = ...) -> None: ...
    BUCKETS_FIELD_NUMBER: _ClassVar[int]
    buckets: _containers.RepeatedCompositeFieldContainer[DescribeRatingDistributionOutput.Bucket]
    def __init__(self, buckets: _Optional[_Iterable[_Union[DescribeRatingDistributionOutput.Bucket, _Mapping]]] = ...) -> None: ...



from eolymp.judge import medal_pb2 as _medal_pb2
from eolymp.judge import score_pb2 as _score_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Result(_message.Message):
    __slots__ = ("participant_id", "member_id", "contest_id", "name", "unofficial", "disqualified", "ghost", "medal", "rank", "rank_lower", "score")
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    UNOFFICIAL_FIELD_NUMBER: _ClassVar[int]
    DISQUALIFIED_FIELD_NUMBER: _ClassVar[int]
    GHOST_FIELD_NUMBER: _ClassVar[int]
    MEDAL_FIELD_NUMBER: _ClassVar[int]
    RANK_FIELD_NUMBER: _ClassVar[int]
    RANK_LOWER_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    participant_id: str
    member_id: str
    contest_id: str
    name: str
    unofficial: bool
    disqualified: bool
    ghost: bool
    medal: _medal_pb2.Medal
    rank: int
    rank_lower: int
    score: _score_pb2.Score
    def __init__(self, participant_id: _Optional[str] = ..., member_id: _Optional[str] = ..., contest_id: _Optional[str] = ..., name: _Optional[str] = ..., unofficial: bool = ..., disqualified: bool = ..., ghost: bool = ..., medal: _Optional[_Union[_medal_pb2.Medal, str]] = ..., rank: _Optional[int] = ..., rank_lower: _Optional[int] = ..., score: _Optional[_Union[_score_pb2.Score, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/printer/printer_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/printer/printer_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.printer import printer_pb2 as eolymp_dot_printer_dot_printer__pb2
from eolymp.printer import printer_job_pb2 as eolymp_dot_printer_dot_printer__job__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/printer/printer_service.proto\x12\x0e\x65olymp.printer\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/printer/printer.proto\x1a eolymp/printer/printer_job.proto\x1a!eolymp/wellknown/expression.proto\">\n\x12\x43reatePrinterInput\x12(\n\x07printer\x18\x01 \x01(\x0b\x32\x17.eolymp.printer.Printer\")\n\x13\x43reatePrinterOutput\x12\x12\n\nprinter_id\x18\x01 \x01(\t\"R\n\x12UpdatePrinterInput\x12\x12\n\nprinter_id\x18\x01 \x01(\t\x12(\n\x07printer\x18\x02 \x01(\x0b\x32\x17.eolymp.printer.Printer\"\x15\n\x13UpdatePrinterOutput\"(\n\x12\x44\x65letePrinterInput\x12\x12\n\nprinter_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65letePrinterOutput\"*\n\x14\x44\x65scribePrinterInput\x12\x12\n\nprinter_id\x18\x01 \x01(\t\"A\n\x15\x44\x65scribePrinterOutput\x12(\n\x07printer\x18\x01 \x01(\x0b\x32\x17.eolymp.printer.Printer\"\x97\x02\n\x11ListPrintersInput\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0e\n\x06search\x18\x1e \x01(\t\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.printer.ListPrintersInput.Filter\x1a\x98\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"K\n\x12ListPrintersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.printer.Printer\"G\n\x15\x43reatePrinterJobInput\x12\x12\n\nprinter_id\x18\x01 \x01(\t\x12\x0e\n\x04html\x18\x03 \x01(\tH\x00\x42\n\n\x08\x64ocument\"(\n\x16\x43reatePrinterJobOutput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"=\n\x17\x44\x65scribePrinterJobInput\x12\x12\n\nprinter_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\"<\n\x18\x44\x65scribePrinterJobOutput\x12 \n\x03job\x18\x01 \x01(\x0b\x32\x13.eolymp.printer.Job\"\xee\x01\n\x14ListPrinterJobsInput\x12\x12\n\nprinter_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12<\n\x07\x66ilters\x18( \x01(\x0b\x32+.eolymp.printer.ListPrinterJobsInput.Filter\x1a\x66\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"J\n\x15ListPrinterJobsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\"\n\x05items\x18\x02 \x03(\x0b\x32\x13.eolymp.printer.Job\";\n\x15\x43\x61ncelPrinterJobInput\x12\x12\n\nprinter_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\"\x18\n\x16\x43\x61ncelPrinterJobOutput\"]\n\x15UpdatePrinterJobInput\x12\x12\n\nprinter_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12 \n\x03job\x18\x03 \x01(\x0b\x32\x13.eolymp.printer.Job\"\x18\n\x16UpdatePrinterJobOutput\";\n\x15\x44\x65letePrinterJobInput\x12\x12\n\nprinter_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\"\x18\n\x16\x44\x65letePrinterJobOutput2\xe0\r\n\x0ePrinterService\x12\x97\x01\n\rCreatePrinter\x12\".eolymp.printer.CreatePrinterInput\x1a#.eolymp.printer.CreatePrinterOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15printer:printer:write\x82\xd3\xe4\x93\x02\x0b\"\t/printers\x12\xa4\x01\n\rUpdatePrinter\x12\".eolymp.printer.UpdatePrinterInput\x1a#.eolymp.printer.UpdatePrinterOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15printer:printer:write\x82\xd3\xe4\x93\x02\x18\"\x16/printers/{printer_id}\x12\xa4\x01\n\rDeletePrinter\x12\".eolymp.printer.DeletePrinterInput\x1a#.eolymp.printer.DeletePrinterOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15printer:printer:write\x82\xd3\xe4\x93\x02\x18*\x16/printers/{printer_id}\x12\xa9\x01\n\x0f\x44\x65scribePrinter\x12$.eolymp.printer.DescribePrinterInput\x1a%.eolymp.printer.DescribePrinterOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14printer:printer:read\x82\xd3\xe4\x93\x02\x18\x12\x16/printers/{printer_id}\x12\x93\x01\n\x0cListPrinters\x12!.eolymp.printer.ListPrintersInput\x1a\".eolymp.printer.ListPrintersOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14printer:printer:read\x82\xd3\xe4\x93\x02\x0b\x12\t/printers\x12\xb2\x01\n\x10\x43reatePrinterJob\x12%.eolymp.printer.CreatePrinterJobInput\x1a&.eolymp.printer.CreatePrinterJobOutput\"O\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15printer:printer:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/printers/{printer_id}/jobs\x12\xc1\x01\n\x12\x44\x65scribePrinterJob\x12\'.eolymp.printer.DescribePrinterJobInput\x1a(.eolymp.printer.DescribePrinterJobOutput\"X\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x18\x8a\xe3\n\x14printer:printer:read\x82\xd3\xe4\x93\x02&\x12$/printers/{printer_id}/jobs/{job_id}\x12\xae\x01\n\x0fListPrinterJobs\x12$.eolymp.printer.ListPrinterJobsInput\x1a%.eolymp.printer.ListPrinterJobsOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x18\x8a\xe3\n\x14printer:printer:read\x82\xd3\xe4\x93\x02\x1d\x12\x1b/printers/{printer_id}/jobs\x12\xbb\x01\n\x10UpdatePrinterJob\x12%.eolymp.printer.UpdatePrinterJobInput\x1a&.eolymp.printer.UpdatePrinterJobOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15printer:printer:write\x82\xd3\xe4\x93\x02&\x1a$/printers/{printer_id}/jobs/{job_id}\x12\xbb\x01\n\x10\x44\x65letePrinterJob\x12%.eolymp.printer.DeletePrinterJobInput\x1a&.eolymp.printer.DeletePrinterJobOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15printer:printer:write\x82\xd3\xe4\x93\x02&*$/printers/{printer_id}/jobs/{job_id}B1Z/github.com/eolymp/go-sdk/eolymp/printer;printerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.printer.printer_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/printer;printer'
  _globals['_PRINTERSERVICE'].methods_by_name['CreatePrinter']._loaded_options = None
  _globals['_PRINTERSERVICE'].methods_by_name['CreatePrinter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025printer:printer:write\202\323\344\223\002\013\"\t/printers'
  _globals['_PRINTERSERVICE'].methods_by_name['UpdatePrinter']._loaded_options = None
  _globals['_PRINTERSERVICE'].methods_by_name['UpdatePrinter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025printer:printer:write\202\323\344\223\002\030\"\026/printers/{printer_id}'
  _globals['_PRINTERSERVICE'].methods_by_name['DeletePrinter']._loaded_options = None
  _globals['_PRINTERSERVICE'].methods_by_name['DeletePrinter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025printer:printer:write\202\323\344\223\002\030*\026/printers/{printer_id}'
  _globals['_PRINTERSERVICE'].methods_by_name['DescribePrinter']._loaded_options = None
  _globals['_PRINTERSERVICE'].methods_by_name['DescribePrinter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024printer:printer:read\202\323\344\223\002\030\022\026/printers/{printer_id}'
  _globals['_PRINTERSERVICE'].methods_by_name['ListPrinters']._loaded_options = None
  _globals['_PRINTERSERVICE'].methods_by_name['ListPrinters']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024printer:printer:read\202\323\344\223\002\013\022\t/printers'
  _globals['_PRINTERSERVICE'].methods_by_name['CreatePrinterJob']._loaded_options = None
  _globals['_PRINTERSERVICE'].methods_by_name['CreatePrinterJob']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025printer:printer:write\202\323\344\223\002\035\"\033/printers/{printer_id}/jobs'
  _globals['_PRINTERSERVICE'].methods_by_name['DescribePrinterJob']._loaded_options = None
  _globals['_PRINTERSERVICE'].methods_by_name['DescribePrinterJob']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\030\212\343\n\024printer:printer:read\202\323\344\223\002&\022$/printers/{printer_id}/jobs/{job_id}'
  _globals['_PRINTERSERVICE'].methods_by_name['ListPrinterJobs']._loaded_options = None
  _globals['_PRINTERSERVICE'].methods_by_name['ListPrinterJobs']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\030\212\343\n\024printer:printer:read\202\323\344\223\002\035\022\033/printers/{printer_id}/jobs'
  _globals['_PRINTERSERVICE'].methods_by_name['UpdatePrinterJob']._loaded_options = None
  _globals['_PRINTERSERVICE'].methods_by_name['UpdatePrinterJob']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025printer:printer:write\202\323\344\223\002&\032$/printers/{printer_id}/jobs/{job_id}'
  _globals['_PRINTERSERVICE'].methods_by_name['DeletePrinterJob']._loaded_options = None
  _globals['_PRINTERSERVICE'].methods_by_name['DeletePrinterJob']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025printer:printer:write\202\323\344\223\002&*$/printers/{printer_id}/jobs/{job_id}'
  _globals['_CREATEPRINTERINPUT']._serialized_start=254
  _globals['_CREATEPRINTERINPUT']._serialized_end=316
  _globals['_CREATEPRINTEROUTPUT']._serialized_start=318
  _globals['_CREATEPRINTEROUTPUT']._serialized_end=359
  _globals['_UPDATEPRINTERINPUT']._serialized_start=361
  _globals['_UPDATEPRINTERINPUT']._serialized_end=443
  _globals['_UPDATEPRINTEROUTPUT']._serialized_start=445
  _globals['_UPDATEPRINTEROUTPUT']._serialized_end=466
  _globals['_DELETEPRINTERINPUT']._serialized_start=468
  _globals['_DELETEPRINTERINPUT']._serialized_end=508
  _globals['_DELETEPRINTEROUTPUT']._serialized_start=510
  _globals['_DELETEPRINTEROUTPUT']._serialized_end=531
  _globals['_DESCRIBEPRINTERINPUT']._serialized_start=533
  _globals['_DESCRIBEPRINTERINPUT']._serialized_end=575
  _globals['_DESCRIBEPRINTEROUTPUT']._serialized_start=577
  _globals['_DESCRIBEPRINTEROUTPUT']._serialized_end=642
  _globals['_LISTPRINTERSINPUT']._serialized_start=645
  _globals['_LISTPRINTERSINPUT']._serialized_end=924
  _globals['_LISTPRINTERSINPUT_FILTER']._serialized_start=772
  _globals['_LISTPRINTERSINPUT_FILTER']._serialized_end=924
  _globals['_LISTPRINTERSOUTPUT']._serialized_start=926
  _globals['_LISTPRINTERSOUTPUT']._serialized_end=1001
  _globals['_CREATEPRINTERJOBINPUT']._serialized_start=1003
  _globals['_CREATEPRINTERJOBINPUT']._serialized_end=1074
  _globals['_CREATEPRINTERJOBOUTPUT']._serialized_start=1076
  _globals['_CREATEPRINTERJOBOUTPUT']._serialized_end=1116
  _globals['_DESCRIBEPRINTERJOBINPUT']._serialized_start=1118
  _globals['_DESCRIBEPRINTERJOBINPUT']._serialized_end=1179
  _globals['_DESCRIBEPRINTERJOBOUTPUT']._serialized_start=1181
  _globals['_DESCRIBEPRINTERJOBOUTPUT']._serialized_end=1241
  _globals['_LISTPRINTERJOBSINPUT']._serialized_start=1244
  _globals['_LISTPRINTERJOBSINPUT']._serialized_end=1482
  _globals['_LISTPRINTERJOBSINPUT_FILTER']._serialized_start=772
  _globals['_LISTPRINTERJOBSINPUT_FILTER']._serialized_end=874
  _globals['_LISTPRINTERJOBSOUTPUT']._serialized_start=1484
  _globals['_LISTPRINTERJOBSOUTPUT']._serialized_end=1558
  _globals['_CANCELPRINTERJOBINPUT']._serialized_start=1560
  _globals['_CANCELPRINTERJOBINPUT']._serialized_end=1619
  _globals['_CANCELPRINTERJOBOUTPUT']._serialized_start=1621
  _globals['_CANCELPRINTERJOBOUTPUT']._serialized_end=1645
  _globals['_UPDATEPRINTERJOBINPUT']._serialized_start=1647
  _globals['_UPDATEPRINTERJOBINPUT']._serialized_end=1740
  _globals['_UPDATEPRINTERJOBOUTPUT']._serialized_start=1742
  _globals['_UPDATEPRINTERJOBOUTPUT']._serialized_end=1766
  _globals['_DELETEPRINTERJOBINPUT']._serialized_start=1768
  _globals['_DELETEPRINTERJOBINPUT']._serialized_end=1827
  _globals['_DELETEPRINTERJOBOUTPUT']._serialized_start=1829
  _globals['_DELETEPRINTERJOBOUTPUT']._serialized_end=1853
  _globals['_PRINTERSERVICE']._serialized_start=1856
  _globals['_PRINTERSERVICE']._serialized_end=3616
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/violation_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/violation_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import violation_pb2 as eolymp_dot_judge_dot_violation__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/judge/violation_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/judge/violation.proto\x1a!eolymp/wellknown/expression.proto\"W\n\x14\x43reateViolationInput\x12*\n\tviolation\x18\x01 \x01(\x0b\x32\x17.eolymp.judge.Violation\x12\x13\n\x0b\x64ont_notify\x18\x02 \x01(\x08\"-\n\x15\x43reateViolationOutput\x12\x14\n\x0cviolation_id\x18\x01 \x01(\t\"\x8c\x01\n\x14UpdateViolationInput\x12\x32\n\x05patch\x18\x03 \x03(\x0e\x32#.eolymp.judge.Violation.Patch.Field\x12\x14\n\x0cviolation_id\x18\x01 \x01(\t\x12*\n\tviolation\x18\x02 \x01(\x0b\x32\x17.eolymp.judge.Violation\"\x17\n\x15UpdateViolationOutput\",\n\x14\x44\x65leteViolationInput\x12\x14\n\x0cviolation_id\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteViolationOutput\".\n\x16\x44\x65scribeViolationInput\x12\x14\n\x0cviolation_id\x18\x01 \x01(\t\"E\n\x17\x44\x65scribeViolationOutput\x12*\n\tviolation\x18\x01 \x01(\x0b\x32\x17.eolymp.judge.Violation\"\xca\x04\n\x13ListViolationsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.judge.ListViolationsInput.Filter\x1a\xd9\x03\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12.\n\x04type\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x33\n\x07summary\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x33\n\tautomatic\x18\n \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x36\n\x0eparticipant_id\x18\x06 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x35\n\rsubmission_id\x18\x08 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\ncreated_by\x18\x07 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x34\n\x0c\x63onfirmed_by\x18\t \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"M\n\x14ListViolationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.judge.Violation2\xcc\x06\n\x10ViolationService\x12\x99\x01\n\x0f\x43reateViolation\x12\".eolymp.judge.CreateViolationInput\x1a#.eolymp.judge.CreateViolationOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\r\"\x0b/violations\x12\xa8\x01\n\x0fUpdateViolation\x12\".eolymp.judge.UpdateViolationInput\x1a#.eolymp.judge.UpdateViolationOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1c\"\x1a/violations/{violation_id}\x12\xa8\x01\n\x0f\x44\x65leteViolation\x12\".eolymp.judge.DeleteViolationInput\x1a#.eolymp.judge.DeleteViolationOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1c*\x1a/violations/{violation_id}\x12\xad\x01\n\x11\x44\x65scribeViolation\x12$.eolymp.judge.DescribeViolationInput\x1a%.eolymp.judge.DescribeViolationOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x1c\x12\x1a/violations/{violation_id}\x12\x95\x01\n\x0eListViolations\x12!.eolymp.judge.ListViolationsInput\x1a\".eolymp.judge.ListViolationsOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\r\x12\x0b/violationsB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.violation_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_VIOLATIONSERVICE'].methods_by_name['CreateViolation']._loaded_options = None
  _globals['_VIOLATIONSERVICE'].methods_by_name['CreateViolation']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\r\"\013/violations'
  _globals['_VIOLATIONSERVICE'].methods_by_name['UpdateViolation']._loaded_options = None
  _globals['_VIOLATIONSERVICE'].methods_by_name['UpdateViolation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\034\"\032/violations/{violation_id}'
  _globals['_VIOLATIONSERVICE'].methods_by_name['DeleteViolation']._loaded_options = None
  _globals['_VIOLATIONSERVICE'].methods_by_name['DeleteViolation']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\034*\032/violations/{violation_id}'
  _globals['_VIOLATIONSERVICE'].methods_by_name['DescribeViolation']._loaded_options = None
  _globals['_VIOLATIONSERVICE'].methods_by_name['DescribeViolation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\034\022\032/violations/{violation_id}'
  _globals['_VIOLATIONSERVICE'].methods_by_name['ListViolations']._loaded_options = None
  _globals['_VIOLATIONSERVICE'].methods_by_name['ListViolations']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\r\022\013/violations'
  _globals['_CREATEVIOLATIONINPUT']._serialized_start=218
  _globals['_CREATEVIOLATIONINPUT']._serialized_end=305
  _globals['_CREATEVIOLATIONOUTPUT']._serialized_start=307
  _globals['_CREATEVIOLATIONOUTPUT']._serialized_end=352
  _globals['_UPDATEVIOLATIONINPUT']._serialized_start=355
  _globals['_UPDATEVIOLATIONINPUT']._serialized_end=495
  _globals['_UPDATEVIOLATIONOUTPUT']._serialized_start=497
  _globals['_UPDATEVIOLATIONOUTPUT']._serialized_end=520
  _globals['_DELETEVIOLATIONINPUT']._serialized_start=522
  _globals['_DELETEVIOLATIONINPUT']._serialized_end=566
  _globals['_DELETEVIOLATIONOUTPUT']._serialized_start=568
  _globals['_DELETEVIOLATIONOUTPUT']._serialized_end=591
  _globals['_DESCRIBEVIOLATIONINPUT']._serialized_start=593
  _globals['_DESCRIBEVIOLATIONINPUT']._serialized_end=639
  _globals['_DESCRIBEVIOLATIONOUTPUT']._serialized_start=641
  _globals['_DESCRIBEVIOLATIONOUTPUT']._serialized_end=710
  _globals['_LISTVIOLATIONSINPUT']._serialized_start=713
  _globals['_LISTVIOLATIONSINPUT']._serialized_end=1299
  _globals['_LISTVIOLATIONSINPUT_FILTER']._serialized_start=826
  _globals['_LISTVIOLATIONSINPUT_FILTER']._serialized_end=1299
  _globals['_LISTVIOLATIONSOUTPUT']._serialized_start=1301
  _globals['_LISTVIOLATIONSOUTPUT']._serialized_end=1378
  _globals['_VIOLATIONSERVICE']._serialized_start=1381
  _globals['_VIOLATIONSERVICE']._serialized_end=2225
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/notify/notification_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/notify/notification_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.notify import notification_pb2 as eolymp_dot_notify_dot_notification__pb2
from eolymp.notify import preferences_pb2 as eolymp_dot_notify_dot_preferences__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/notify/notification_service.proto\x12\reolymp.notify\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a eolymp/notify/notification.proto\x1a\x1f\x65olymp/notify/preferences.proto\"F\n\x11NotificationEvent\x12\x31\n\x0cnotification\x18\x01 \x01(\x0b\x32\x1b.eolymp.notify.Notification\"L\n\x17\x43reateNotificationInput\x12\x31\n\x0cnotification\x18\x01 \x01(\x0b\x32\x1b.eolymp.notify.Notification\"\x1a\n\x18\x43reateNotificationOutput\"4\n\x19\x44\x65scribeNotificationInput\x12\x17\n\x0fnotification_id\x18\x01 \x01(\t\"O\n\x1a\x44\x65scribeNotificationOutput\x12\x31\n\x0cnotification\x18\x01 \x01(\x0b\x32\x1b.eolymp.notify.Notification\"0\n\x15ReadNotificationInput\x12\x17\n\x0fnotification_id\x18\x01 \x01(\t\"\x18\n\x16ReadNotificationOutput\"2\n\x17\x44\x65leteNotificationInput\x12\x17\n\x0fnotification_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteNotificationOutput\"5\n\x16ListNotificationsInput\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\"T\n\x17ListNotificationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.notify.Notification\",\n\x18\x44\x65scribePreferencesInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"L\n\x19\x44\x65scribePreferencesOutput\x12/\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x1a.eolymp.notify.Preferences\"\xed\x01\n\x16UpdatePreferencesInput\x12:\n\x05patch\x18\x03 \x03(\x0e\x32+.eolymp.notify.UpdatePreferencesInput.Patch\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12/\n\x0bpreferences\x18\x02 \x01(\x0b\x32\x1a.eolymp.notify.Preferences\"T\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x11\n\rSUBSCRIPTIONS\x10\n\x12\x15\n\x11SUBSCRIPTIONS_ADD\x10\x0b\x12\x18\n\x14SUBSCRIPTIONS_REMOVE\x10\x0c\"\x19\n\x17UpdatePreferencesOutput2\xb7\x08\n\x13NotificationService\x12v\n\x12\x43reateNotification\x12&.eolymp.notify.CreateNotificationInput\x1a\'.eolymp.notify.CreateNotificationOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12\xa4\x01\n\x14\x44\x65scribeNotification\x12(.eolymp.notify.DescribeNotificationInput\x1a).eolymp.notify.DescribeNotificationOutput\"7\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\"\x12 /notifications/{notification_id}\x12\x9d\x01\n\x10ReadNotification\x12$.eolymp.notify.ReadNotificationInput\x1a%.eolymp.notify.ReadNotificationOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\'\"%/notifications/{notification_id}/read\x12\x9e\x01\n\x12\x44\x65leteNotification\x12&.eolymp.notify.DeleteNotificationInput\x1a\'.eolymp.notify.DeleteNotificationOutput\"7\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\"* /notifications/{notification_id}\x12\x89\x01\n\x11ListNotifications\x12%.eolymp.notify.ListNotificationsInput\x1a&.eolymp.notify.ListNotificationsOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x10\x12\x0e/notifications\x12\x9b\x01\n\x13\x44\x65scribePreferences\x12\'.eolymp.notify.DescribePreferencesInput\x1a(.eolymp.notify.DescribePreferencesOutput\"1\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1c\x12\x1a/preferences/notifications\x12\x95\x01\n\x11UpdatePreferences\x12%.eolymp.notify.UpdatePreferencesInput\x1a&.eolymp.notify.UpdatePreferencesOutput\"1\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1c\"\x1a/preferences/notificationsB/Z-github.com/eolymp/go-sdk/eolymp/notify;notifyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.notify.notification_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/notify;notify'
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['CreateNotification']._loaded_options = None
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['CreateNotification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['DescribeNotification']._loaded_options = None
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['DescribeNotification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\"\022 /notifications/{notification_id}'
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['ReadNotification']._loaded_options = None
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['ReadNotification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\'\"%/notifications/{notification_id}/read'
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['DeleteNotification']._loaded_options = None
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['DeleteNotification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\"* /notifications/{notification_id}'
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['ListNotifications']._loaded_options = None
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['ListNotifications']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\020\022\016/notifications'
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['DescribePreferences']._loaded_options = None
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['DescribePreferences']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\323\344\223\002\034\022\032/preferences/notifications'
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['UpdatePreferences']._loaded_options = None
  _globals['_NOTIFICATIONSERVICE'].methods_by_name['UpdatePreferences']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\034\"\032/preferences/notifications'
  _globals['_NOTIFICATIONEVENT']._serialized_start=193
  _globals['_NOTIFICATIONEVENT']._serialized_end=263
  _globals['_CREATENOTIFICATIONINPUT']._serialized_start=265
  _globals['_CREATENOTIFICATIONINPUT']._serialized_end=341
  _globals['_CREATENOTIFICATIONOUTPUT']._serialized_start=343
  _globals['_CREATENOTIFICATIONOUTPUT']._serialized_end=369
  _globals['_DESCRIBENOTIFICATIONINPUT']._serialized_start=371
  _globals['_DESCRIBENOTIFICATIONINPUT']._serialized_end=423
  _globals['_DESCRIBENOTIFICATIONOUTPUT']._serialized_start=425
  _globals['_DESCRIBENOTIFICATIONOUTPUT']._serialized_end=504
  _globals['_READNOTIFICATIONINPUT']._serialized_start=506
  _globals['_READNOTIFICATIONINPUT']._serialized_end=554
  _globals['_READNOTIFICATIONOUTPUT']._serialized_start=556
  _globals['_READNOTIFICATIONOUTPUT']._serialized_end=580
  _globals['_DELETENOTIFICATIONINPUT']._serialized_start=582
  _globals['_DELETENOTIFICATIONINPUT']._serialized_end=632
  _globals['_DELETENOTIFICATIONOUTPUT']._serialized_start=634
  _globals['_DELETENOTIFICATIONOUTPUT']._serialized_end=660
  _globals['_LISTNOTIFICATIONSINPUT']._serialized_start=662
  _globals['_LISTNOTIFICATIONSINPUT']._serialized_end=715
  _globals['_LISTNOTIFICATIONSOUTPUT']._serialized_start=717
  _globals['_LISTNOTIFICATIONSOUTPUT']._serialized_end=801
  _globals['_DESCRIBEPREFERENCESINPUT']._serialized_start=803
  _globals['_DESCRIBEPREFERENCESINPUT']._serialized_end=847
  _globals['_DESCRIBEPREFERENCESOUTPUT']._serialized_start=849
  _globals['_DESCRIBEPREFERENCESOUTPUT']._serialized_end=925
  _globals['_UPDATEPREFERENCESINPUT']._serialized_start=928
  _globals['_UPDATEPREFERENCESINPUT']._serialized_end=1165
  _globals['_UPDATEPREFERENCESINPUT_PATCH']._serialized_start=1081
  _globals['_UPDATEPREFERENCESINPUT_PATCH']._serialized_end=1165
  _globals['_UPDATEPREFERENCESOUTPUT']._serialized_start=1167
  _globals['_UPDATEPREFERENCESOUTPUT']._serialized_end=1192
  _globals['_NOTIFICATIONSERVICE']._serialized_start=1195
  _globals['_NOTIFICATIONSERVICE']._serialized_end=2274
# @@protoc_insertion_point(module_scope)



import datetime

from eolymp.runtime import runtime_pb2 as _runtime_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Contest(_message.Message):
    __slots__ = ("id", "url", "name", "image_url", "starts_at", "ends_at", "duration", "status", "visibility", "participation_mode", "join_unofficially", "require_admission", "allow_pause", "allow_finish_early", "allow_upsolve", "allow_followup", "format", "key", "problem_count", "problem_count_hidden", "participant_count", "participant_count_hidden", "featured_until", "printer_id", "classification", "scoreboard_config", "environment_config", "certification_config", "plagiarism_config", "staff")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATUS_UNKNOWN: _ClassVar[Contest.Status]
        SCHEDULED: _ClassVar[Contest.Status]
        OPEN: _ClassVar[Contest.Status]
        COMPLETE: _ClassVar[Contest.Status]
        SUSPENDED: _ClassVar[Contest.Status]
        FROZEN: _ClassVar[Contest.Status]
        FINALIZED: _ClassVar[Contest.Status]
    STATUS_UNKNOWN: Contest.Status
    SCHEDULED: Contest.Status
    OPEN: Contest.Status
    COMPLETE: Contest.Status
    SUSPENDED: Contest.Status
    FROZEN: Contest.Status
    FINALIZED: Contest.Status
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        VISIBILITY_UNKNOWN: _ClassVar[Contest.Visibility]
        PUBLIC: _ClassVar[Contest.Visibility]
        UNLISTED: _ClassVar[Contest.Visibility]
        PRIVATE: _ClassVar[Contest.Visibility]
    VISIBILITY_UNKNOWN: Contest.Visibility
    PUBLIC: Contest.Visibility
    UNLISTED: Contest.Visibility
    PRIVATE: Contest.Visibility
    class ParticipationMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PARTICIPATION_MODE_UNKNOWN: _ClassVar[Contest.ParticipationMode]
        ONLINE: _ClassVar[Contest.ParticipationMode]
        VIRTUAL: _ClassVar[Contest.ParticipationMode]
    PARTICIPATION_MODE_UNKNOWN: Contest.ParticipationMode
    ONLINE: Contest.ParticipationMode
    VIRTUAL: Contest.ParticipationMode
    class Format(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        FORMAT_UNKNOWN: _ClassVar[Contest.Format]
        IOI: _ClassVar[Contest.Format]
        ICPC: _ClassVar[Contest.Format]
    FORMAT_UNKNOWN: Contest.Format
    IOI: Contest.Format
    ICPC: Contest.Format
    class Patch(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN: _ClassVar[Contest.Patch.Field]
            NAME: _ClassVar[Contest.Patch.Field]
            IMAGE_URL: _ClassVar[Contest.Patch.Field]
            STARTS_AT: _ClassVar[Contest.Patch.Field]
            ENDS_AT: _ClassVar[Contest.Patch.Field]
            DURATION: _ClassVar[Contest.Patch.Field]
            VISIBILITY: _ClassVar[Contest.Patch.Field]
            JOIN_UNOFFICIALLY: _ClassVar[Contest.Patch.Field]
            PARTICIPATION_MODE: _ClassVar[Contest.Patch.Field]
            REQUIRE_ADMISSION: _ClassVar[Contest.Patch.Field]
            ALLOW_PAUSE: _ClassVar[Contest.Patch.Field]
            ALLOW_FINISH_EARLY: _ClassVar[Contest.Patch.Field]
            ALLOW_UPSOLVE: _ClassVar[Contest.Patch.Field]
            ALLOW_FOLLOWUP: _ClassVar[Contest.Patch.Field]
            FORMAT: _ClassVar[Contest.Patch.Field]
            KEY: _ClassVar[Contest.Patch.Field]
            PROBLEM_COUNT_HIDDEN: _ClassVar[Contest.Patch.Field]
            PARTICIPANT_COUNT_HIDDEN: _ClassVar[Contest.Patch.Field]
            FEATURED_UNTIL: _ClassVar[Contest.Patch.Field]
            PRINTER: _ClassVar[Contest.Patch.Field]
            CLASSIFICATION: _ClassVar[Contest.Patch.Field]
            SCOREBOARD_CONFIG: _ClassVar[Contest.Patch.Field]
            CERTIFICATION_CONFIG: _ClassVar[Contest.Patch.Field]
            ENVIRONMENT_CONFIG: _ClassVar[Contest.Patch.Field]
            PLAGIARISM_CONFIG: _ClassVar[Contest.Patch.Field]
        UNKNOWN: Contest.Patch.Field
        NAME: Contest.Patch.Field
        IMAGE_URL: Contest.Patch.Field
        STARTS_AT: Contest.Patch.Field
        ENDS_AT: Contest.Patch.Field
        DURATION: Contest.Patch.Field
        VISIBILITY: Contest.Patch.Field
        JOIN_UNOFFICIALLY: Contest.Patch.Field
        PARTICIPATION_MODE: Contest.Patch.Field
        REQUIRE_ADMISSION: Contest.Patch.Field
        ALLOW_PAUSE: Contest.Patch.Field
        ALLOW_FINISH_EARLY: Contest.Patch.Field
        ALLOW_UPSOLVE: Contest.Patch.Field
        ALLOW_FOLLOWUP: Contest.Patch.Field
        FORMAT: Contest.Patch.Field
        KEY: Contest.Patch.Field
        PROBLEM_COUNT_HIDDEN: Contest.Patch.Field
        PARTICIPANT_COUNT_HIDDEN: Contest.Patch.Field
        FEATURED_UNTIL: Contest.Patch.Field
        PRINTER: Contest.Patch.Field
        CLASSIFICATION: Contest.Patch.Field
        SCOREBOARD_CONFIG: Contest.Patch.Field
        CERTIFICATION_CONFIG: Contest.Patch.Field
        ENVIRONMENT_CONFIG: Contest.Patch.Field
        PLAGIARISM_CONFIG: Contest.Patch.Field
        def __init__(self) -> None: ...
    class Extra(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN: _ClassVar[Contest.Extra.Field]
            CLASSIFICATION: _ClassVar[Contest.Extra.Field]
            SCOREBOARD_CONFIG: _ClassVar[Contest.Extra.Field]
            CERTIFICATION_CONFIG: _ClassVar[Contest.Extra.Field]
            ENVIRONMENT_CONFIG: _ClassVar[Contest.Extra.Field]
            PLAGIARISM_CONFIG: _ClassVar[Contest.Extra.Field]
            STAFF: _ClassVar[Contest.Extra.Field]
        UNKNOWN: Contest.Extra.Field
        CLASSIFICATION: Contest.Extra.Field
        SCOREBOARD_CONFIG: Contest.Extra.Field
        CERTIFICATION_CONFIG: Contest.Extra.Field
        ENVIRONMENT_CONFIG: Contest.Extra.Field
        PLAGIARISM_CONFIG: Contest.Extra.Field
        STAFF: Contest.Extra.Field
        def __init__(self) -> None: ...
    class Classification(_message.Message):
        __slots__ = ("year", "series", "scale", "difficulty", "country", "region", "city")
        class Scale(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_SCALE: _ClassVar[Contest.Classification.Scale]
            LOCAL: _ClassVar[Contest.Classification.Scale]
            REGIONAL: _ClassVar[Contest.Classification.Scale]
            NATIONAL: _ClassVar[Contest.Classification.Scale]
            INTERNATIONAL: _ClassVar[Contest.Classification.Scale]
        UNKNOWN_SCALE: Contest.Classification.Scale
        LOCAL: Contest.Classification.Scale
        REGIONAL: Contest.Classification.Scale
        NATIONAL: Contest.Classification.Scale
        INTERNATIONAL: Contest.Classification.Scale
        YEAR_FIELD_NUMBER: _ClassVar[int]
        SERIES_FIELD_NUMBER: _ClassVar[int]
        SCALE_FIELD_NUMBER: _ClassVar[int]
        DIFFICULTY_FIELD_NUMBER: _ClassVar[int]
        COUNTRY_FIELD_NUMBER: _ClassVar[int]
        REGION_FIELD_NUMBER: _ClassVar[int]
        CITY_FIELD_NUMBER: _ClassVar[int]
        year: int
        series: str
        scale: Contest.Classification.Scale
        difficulty: int
        country: str
        region: str
        city: str
        def __init__(self, year: _Optional[int] = ..., series: _Optional[str] = ..., scale: _Optional[_Union[Contest.Classification.Scale, str]] = ..., difficulty: _Optional[int] = ..., country: _Optional[str] = ..., region: _Optional[str] = ..., city: _Optional[str] = ...) -> None: ...
    class ScoreboardConfig(_message.Message):
        __slots__ = ("visibility", "freezing_time", "unfreeze_delay", "attempt_penalty", "tie_breaker", "no_spoiler_ui", "share_key")
        class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_VISIBILITY: _ClassVar[Contest.ScoreboardConfig.Visibility]
            INVISIBLE: _ClassVar[Contest.ScoreboardConfig.Visibility]
            INTERNAL: _ClassVar[Contest.ScoreboardConfig.Visibility]
            PUBLIC: _ClassVar[Contest.ScoreboardConfig.Visibility]
        UNKNOWN_VISIBILITY: Contest.ScoreboardConfig.Visibility
        INVISIBLE: Contest.ScoreboardConfig.Visibility
        INTERNAL: Contest.ScoreboardConfig.Visibility
        PUBLIC: Contest.ScoreboardConfig.Visibility
        VISIBILITY_FIELD_NUMBER: _ClassVar[int]
        FREEZING_TIME_FIELD_NUMBER: _ClassVar[int]
        UNFREEZE_DELAY_FIELD_NUMBER: _ClassVar[int]
        ATTEMPT_PENALTY_FIELD_NUMBER: _ClassVar[int]
        TIE_BREAKER_FIELD_NUMBER: _ClassVar[int]
        NO_SPOILER_UI_FIELD_NUMBER: _ClassVar[int]
        SHARE_KEY_FIELD_NUMBER: _ClassVar[int]
        visibility: Contest.ScoreboardConfig.Visibility
        freezing_time: int
        unfreeze_delay: int
        attempt_penalty: int
        tie_breaker: str
        no_spoiler_ui: bool
        share_key: str
        def __init__(self, visibility: _Optional[_Union[Contest.ScoreboardConfig.Visibility, str]] = ..., freezing_time: _Optional[int] = ..., unfreeze_delay: _Optional[int] = ..., attempt_penalty: _Optional[int] = ..., tie_breaker: _Optional[str] = ..., no_spoiler_ui: bool = ..., share_key: _Optional[str] = ...) -> None: ...
    class CertificationConfig(_message.Message):
        __slots__ = ("enabled", "affiliation", "signers")
        class Signer(_message.Message):
            __slots__ = ("name", "title")
            NAME_FIELD_NUMBER: _ClassVar[int]
            TITLE_FIELD_NUMBER: _ClassVar[int]
            name: str
            title: str
            def __init__(self, name: _Optional[str] = ..., title: _Optional[str] = ...) -> None: ...
        ENABLED_FIELD_NUMBER: _ClassVar[int]
        AFFILIATION_FIELD_NUMBER: _ClassVar[int]
        SIGNERS_FIELD_NUMBER: _ClassVar[int]
        enabled: bool
        affiliation: str
        signers: _containers.RepeatedCompositeFieldContainer[Contest.CertificationConfig.Signer]
        def __init__(self, enabled: bool = ..., affiliation: _Optional[str] = ..., signers: _Optional[_Iterable[_Union[Contest.CertificationConfig.Signer, _Mapping]]] = ...) -> None: ...
    class EnvironmentConfig(_message.Message):
        __slots__ = ("runtimes",)
        RUNTIMES_FIELD_NUMBER: _ClassVar[int]
        runtimes: _containers.RepeatedCompositeFieldContainer[_runtime_pb2.Runtime]
        def __init__(self, runtimes: _Optional[_Iterable[_Union[_runtime_pb2.Runtime, _Mapping]]] = ...) -> None: ...
    class PlagiarismConfig(_message.Message):
        __slots__ = ("check_genai_use",)
        CHECK_GENAI_USE_FIELD_NUMBER: _ClassVar[int]
        check_genai_use: bool
        def __init__(self, check_genai_use: bool = ...) -> None: ...
    class Staff(_message.Message):
        __slots__ = ("member_id", "display_name", "role")
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
        ROLE_FIELD_NUMBER: _ClassVar[int]
        member_id: str
        display_name: str
        role: str
        def __init__(self, member_id: _Optional[str] = ..., display_name: _Optional[str] = ..., role: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    STARTS_AT_FIELD_NUMBER: _ClassVar[int]
    ENDS_AT_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    PARTICIPATION_MODE_FIELD_NUMBER: _ClassVar[int]
    JOIN_UNOFFICIALLY_FIELD_NUMBER: _ClassVar[int]
    REQUIRE_ADMISSION_FIELD_NUMBER: _ClassVar[int]
    ALLOW_PAUSE_FIELD_NUMBER: _ClassVar[int]
    ALLOW_FINISH_EARLY_FIELD_NUMBER: _ClassVar[int]
    ALLOW_UPSOLVE_FIELD_NUMBER: _ClassVar[int]
    ALLOW_FOLLOWUP_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_COUNT_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_COUNT_HIDDEN_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_COUNT_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_COUNT_HIDDEN_FIELD_NUMBER: _ClassVar[int]
    FEATURED_UNTIL_FIELD_NUMBER: _ClassVar[int]
    PRINTER_ID_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_CONFIG_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_CONFIG_FIELD_NUMBER: _ClassVar[int]
    CERTIFICATION_CONFIG_FIELD_NUMBER: _ClassVar[int]
    PLAGIARISM_CONFIG_FIELD_NUMBER: _ClassVar[int]
    STAFF_FIELD_NUMBER: _ClassVar[int]
    id: str
    url: str
    name: str
    image_url: str
    starts_at: _timestamp_pb2.Timestamp
    ends_at: _timestamp_pb2.Timestamp
    duration: int
    status: Contest.Status
    visibility: Contest.Visibility
    participation_mode: Contest.ParticipationMode
    join_unofficially: bool
    require_admission: bool
    allow_pause: bool
    allow_finish_early: bool
    allow_upsolve: bool
    allow_followup: bool
    format: Contest.Format
    key: str
    problem_count: int
    problem_count_hidden: bool
    participant_count: int
    participant_count_hidden: bool
    featured_until: _timestamp_pb2.Timestamp
    printer_id: str
    classification: Contest.Classification
    scoreboard_config: Contest.ScoreboardConfig
    environment_config: Contest.EnvironmentConfig
    certification_config: Contest.CertificationConfig
    plagiarism_config: Contest.PlagiarismConfig
    staff: _containers.RepeatedCompositeFieldContainer[Contest.Staff]
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., name: _Optional[str] = ..., image_url: _Optional[str] = ..., starts_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., ends_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[int] = ..., status: _Optional[_Union[Contest.Status, str]] = ..., visibility: _Optional[_Union[Contest.Visibility, str]] = ..., participation_mode: _Optional[_Union[Contest.ParticipationMode, str]] = ..., join_unofficially: bool = ..., require_admission: bool = ..., allow_pause: bool = ..., allow_finish_early: bool = ..., allow_upsolve: bool = ..., allow_followup: bool = ..., format: _Optional[_Union[Contest.Format, str]] = ..., key: _Optional[str] = ..., problem_count: _Optional[int] = ..., problem_count_hidden: bool = ..., participant_count: _Optional[int] = ..., participant_count_hidden: bool = ..., featured_until: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., printer_id: _Optional[str] = ..., classification: _Optional[_Union[Contest.Classification, _Mapping]] = ..., scoreboard_config: _Optional[_Union[Contest.ScoreboardConfig, _Mapping]] = ..., environment_config: _Optional[_Union[Contest.EnvironmentConfig, _Mapping]] = ..., certification_config: _Optional[_Union[Contest.CertificationConfig, _Mapping]] = ..., plagiarism_config: _Optional[_Union[Contest.PlagiarismConfig, _Mapping]] = ..., staff: _Optional[_Iterable[_Union[Contest.Staff, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/contest.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/contest.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.runtime import runtime_pb2 as eolymp_dot_runtime_dot_runtime__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/judge/contest.proto\x12\x0c\x65olymp.judge\x1a\x1c\x65olymp/runtime/runtime.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xba\x17\n\x07\x43ontest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\timage_url\x18\x04 \x01(\t\x12-\n\tstarts_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65nds_at\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64uration\x18\x0c \x01(\r\x12,\n\x06status\x18\x14 \x01(\x0e\x32\x1c.eolymp.judge.Contest.Status\x12\x34\n\nvisibility\x18\x1e \x01(\x0e\x32 .eolymp.judge.Contest.Visibility\x12\x43\n\x12participation_mode\x18\x1f \x01(\x0e\x32\'.eolymp.judge.Contest.ParticipationMode\x12\x19\n\x11join_unofficially\x18! \x01(\x08\x12\x19\n\x11require_admission\x18# \x01(\x08\x12\x13\n\x0b\x61llow_pause\x18$ \x01(\x08\x12\x1a\n\x12\x61llow_finish_early\x18% \x01(\x08\x12\x15\n\rallow_upsolve\x18& \x01(\x08\x12\x16\n\x0e\x61llow_followup\x18\' \x01(\x08\x12,\n\x06\x66ormat\x18  \x01(\x0e\x32\x1c.eolymp.judge.Contest.Format\x12\x0b\n\x03key\x18( \x01(\t\x12\x15\n\rproblem_count\x18< \x01(\r\x12\x1c\n\x14problem_count_hidden\x18= \x01(\x08\x12\x19\n\x11participant_count\x18> \x01(\r\x12 \n\x18participant_count_hidden\x18? \x01(\x08\x12\x32\n\x0e\x66\x65\x61tured_until\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nprinter_id\x18G \x01(\t\x12<\n\x0e\x63lassification\x18n \x01(\x0b\x32$.eolymp.judge.Contest.Classification\x12\x41\n\x11scoreboard_config\x18i \x01(\x0b\x32&.eolymp.judge.Contest.ScoreboardConfig\x12\x43\n\x12\x65nvironment_config\x18o \x01(\x0b\x32\'.eolymp.judge.Contest.EnvironmentConfig\x12G\n\x14\x63\x65rtification_config\x18p \x01(\x0b\x32).eolymp.judge.Contest.CertificationConfig\x12\x41\n\x11plagiarism_config\x18q \x01(\x0b\x32&.eolymp.judge.Contest.PlagiarismConfig\x12*\n\x05staff\x18x \x03(\x0b\x32\x1b.eolymp.judge.Contest.Staff\x1a\xed\x03\n\x05Patch\"\xe3\x03\n\x05\x46ield\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NAME\x10\x02\x12\r\n\tIMAGE_URL\x10\x0e\x12\r\n\tSTARTS_AT\x10\x03\x12\x0b\n\x07\x45NDS_AT\x10\x04\x12\x0c\n\x08\x44URATION\x10\x05\x12\x0e\n\nVISIBILITY\x10\x06\x12\x15\n\x11JOIN_UNOFFICIALLY\x10\x07\x12\x16\n\x12PARTICIPATION_MODE\x10\x08\x12\x15\n\x11REQUIRE_ADMISSION\x10\x10\x12\x0f\n\x0b\x41LLOW_PAUSE\x10\x11\x12\x16\n\x12\x41LLOW_FINISH_EARLY\x10\x12\x12\x11\n\rALLOW_UPSOLVE\x10x\x12\x12\n\x0e\x41LLOW_FOLLOWUP\x10y\x12\n\n\x06\x46ORMAT\x10\n\x12\x07\n\x03KEY\x10\x0b\x12\x18\n\x14PROBLEM_COUNT_HIDDEN\x10\x0c\x12\x1c\n\x18PARTICIPANT_COUNT_HIDDEN\x10\r\x12\x12\n\x0e\x46\x45\x41TURED_UNTIL\x10\t\x12\x0b\n\x07PRINTER\x10\x0f\x12\x12\n\x0e\x43LASSIFICATION\x10\x64\x12\x16\n\x11SCOREBOARD_CONFIG\x10\x96\x01\x12\x19\n\x14\x43\x45RTIFICATION_CONFIG\x10\x97\x01\x12\x17\n\x12\x45NVIRONMENT_CONFIG\x10\x98\x01\x12\x16\n\x11PLAGIARISM_CONFIG\x10\x99\x01\x1a\x9d\x01\n\x05\x45xtra\"\x93\x01\n\x05\x46ield\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x43LASSIFICATION\x10\x01\x12\x15\n\x11SCOREBOARD_CONFIG\x10\x02\x12\x18\n\x14\x43\x45RTIFICATION_CONFIG\x10\x03\x12\x16\n\x12\x45NVIRONMENT_CONFIG\x10\x04\x12\x15\n\x11PLAGIARISM_CONFIG\x10\x06\x12\t\n\x05STAFF\x10\x05\x1a\x82\x02\n\x0e\x43lassification\x12\x0c\n\x04year\x18\x01 \x01(\r\x12\x0e\n\x06series\x18\x02 \x01(\t\x12\x39\n\x05scale\x18\x03 \x01(\x0e\x32*.eolymp.judge.Contest.Classification.Scale\x12\x12\n\ndifficulty\x18\x04 \x01(\r\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04\x63ity\x18\x07 \x01(\t\"T\n\x05Scale\x12\x11\n\rUNKNOWN_SCALE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08REGIONAL\x10\x02\x12\x0c\n\x08NATIONAL\x10\x03\x12\x11\n\rINTERNATIONAL\x10\x04\x1a\xaf\x02\n\x10ScoreboardConfig\x12\x45\n\nvisibility\x18\x01 \x01(\x0e\x32\x31.eolymp.judge.Contest.ScoreboardConfig.Visibility\x12\x15\n\rfreezing_time\x18\x02 \x01(\r\x12\x16\n\x0eunfreeze_delay\x18\x03 \x01(\x05\x12\x17\n\x0f\x61ttempt_penalty\x18\x04 \x01(\r\x12\x13\n\x0btie_breaker\x18\x05 \x01(\t\x12\x15\n\rno_spoiler_ui\x18\x06 \x01(\x08\x12\x11\n\tshare_key\x18\x07 \x01(\t\"M\n\nVisibility\x12\x16\n\x12UNKNOWN_VISIBILITY\x10\x00\x12\r\n\tINVISIBLE\x10\x01\x12\x0c\n\x08INTERNAL\x10\x02\x12\n\n\x06PUBLIC\x10\x03\x1a\xa5\x01\n\x13\x43\x65rtificationConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x13\n\x0b\x61\x66\x66iliation\x18\x02 \x01(\t\x12\x41\n\x07signers\x18\x03 \x03(\x0b\x32\x30.eolymp.judge.Contest.CertificationConfig.Signer\x1a%\n\x06Signer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x1a>\n\x11\x45nvironmentConfig\x12)\n\x08runtimes\x18\x02 \x03(\x0b\x32\x17.eolymp.runtime.Runtime\x1a+\n\x10PlagiarismConfig\x12\x17\n\x0f\x63heck_genai_use\x18\x01 \x01(\x08\x1a>\n\x05Staff\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\"m\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x08\n\x04OPEN\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\r\n\tSUSPENDED\x10\x04\x12\n\n\x06\x46ROZEN\x10\x05\x12\r\n\tFINALIZED\x10\x06\"K\n\nVisibility\x12\x16\n\x12VISIBILITY_UNKNOWN\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0c\n\x08UNLISTED\x10\x02\x12\x0b\n\x07PRIVATE\x10\x03\"L\n\x11ParticipationMode\x12\x1e\n\x1aPARTICIPATION_MODE_UNKNOWN\x10\x00\x12\n\n\x06ONLINE\x10\x01\x12\x0b\n\x07VIRTUAL\x10\x02\"/\n\x06\x46ormat\x12\x12\n\x0e\x46ORMAT_UNKNOWN\x10\x00\x12\x07\n\x03IOI\x10\x01\x12\x08\n\x04ICPC\x10\x02\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.contest_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_CONTEST']._serialized_start=108
  _globals['_CONTEST']._serialized_end=3110
  _globals['_CONTEST_PATCH']._serialized_start=1234
  _globals['_CONTEST_PATCH']._serialized_end=1727
  _globals['_CONTEST_PATCH_FIELD']._serialized_start=1244
  _globals['_CONTEST_PATCH_FIELD']._serialized_end=1727
  _globals['_CONTEST_EXTRA']._serialized_start=1730
  _globals['_CONTEST_EXTRA']._serialized_end=1887
  _globals['_CONTEST_EXTRA_FIELD']._serialized_start=1740
  _globals['_CONTEST_EXTRA_FIELD']._serialized_end=1887
  _globals['_CONTEST_CLASSIFICATION']._serialized_start=1890
  _globals['_CONTEST_CLASSIFICATION']._serialized_end=2148
  _globals['_CONTEST_CLASSIFICATION_SCALE']._serialized_start=2064
  _globals['_CONTEST_CLASSIFICATION_SCALE']._serialized_end=2148
  _globals['_CONTEST_SCOREBOARDCONFIG']._serialized_start=2151
  _globals['_CONTEST_SCOREBOARDCONFIG']._serialized_end=2454
  _globals['_CONTEST_SCOREBOARDCONFIG_VISIBILITY']._serialized_start=2377
  _globals['_CONTEST_SCOREBOARDCONFIG_VISIBILITY']._serialized_end=2454
  _globals['_CONTEST_CERTIFICATIONCONFIG']._serialized_start=2457
  _globals['_CONTEST_CERTIFICATIONCONFIG']._serialized_end=2622
  _globals['_CONTEST_CERTIFICATIONCONFIG_SIGNER']._serialized_start=2585
  _globals['_CONTEST_CERTIFICATIONCONFIG_SIGNER']._serialized_end=2622
  _globals['_CONTEST_ENVIRONMENTCONFIG']._serialized_start=2624
  _globals['_CONTEST_ENVIRONMENTCONFIG']._serialized_end=2686
  _globals['_CONTEST_PLAGIARISMCONFIG']._serialized_start=2688
  _globals['_CONTEST_PLAGIARISMCONFIG']._serialized_end=2731
  _globals['_CONTEST_STAFF']._serialized_start=2733
  _globals['_CONTEST_STAFF']._serialized_end=2795
  _globals['_CONTEST_STATUS']._serialized_start=2797
  _globals['_CONTEST_STATUS']._serialized_end=2906
  _globals['_CONTEST_VISIBILITY']._serialized_start=2908
  _globals['_CONTEST_VISIBILITY']._serialized_end=2983
  _globals['_CONTEST_PARTICIPATIONMODE']._serialized_start=2985
  _globals['_CONTEST_PARTICIPATIONMODE']._serialized_end=3061
  _globals['_CONTEST_FORMAT']._serialized_start=3063
  _globals['_CONTEST_FORMAT']._serialized_end=3110
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.l10n import project_pb2 as _project_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListProjectsInput(_message.Message):
    __slots__ = ("offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("id",)
        ID_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListProjectsInput.Filter
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListProjectsInput.Filter, _Mapping]] = ...) -> None: ...

class ListProjectsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_project_pb2.Project]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_project_pb2.Project, _Mapping]]] = ...) -> None: ...

class DescribeProjectInput(_message.Message):
    __slots__ = ("project_id",)
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    def __init__(self, project_id: _Optional[str] = ...) -> None: ...

class DescribeProjectOutput(_message.Message):
    __slots__ = ("project",)
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: _project_pb2.Project
    def __init__(self, project: _Optional[_Union[_project_pb2.Project, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import editorial_pb2 as _editorial_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListEditorialsInput(_message.Message):
    __slots__ = ("offset", "size", "version", "render", "extra")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    version: int
    render: bool
    extra: _containers.RepeatedScalarFieldContainer[_editorial_pb2.Editorial.Extra]
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., version: _Optional[int] = ..., render: bool = ..., extra: _Optional[_Iterable[_Union[_editorial_pb2.Editorial.Extra, str]]] = ...) -> None: ...

class ListEditorialsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_editorial_pb2.Editorial]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_editorial_pb2.Editorial, _Mapping]]] = ...) -> None: ...

class DescribeEditorialInput(_message.Message):
    __slots__ = ("editorial_id", "version", "render", "extra")
    EDITORIAL_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    editorial_id: str
    version: int
    render: bool
    extra: _containers.RepeatedScalarFieldContainer[_editorial_pb2.Editorial.Extra]
    def __init__(self, editorial_id: _Optional[str] = ..., version: _Optional[int] = ..., render: bool = ..., extra: _Optional[_Iterable[_Union[_editorial_pb2.Editorial.Extra, str]]] = ...) -> None: ...

class DescribeEditorialOutput(_message.Message):
    __slots__ = ("editorial",)
    EDITORIAL_FIELD_NUMBER: _ClassVar[int]
    editorial: _editorial_pb2.Editorial
    def __init__(self, editorial: _Optional[_Union[_editorial_pb2.Editorial, _Mapping]] = ...) -> None: ...

class LookupEditorialInput(_message.Message):
    __slots__ = ("locale", "version", "render", "extra")
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    locale: str
    version: int
    render: bool
    extra: _containers.RepeatedScalarFieldContainer[_editorial_pb2.Editorial.Extra]
    def __init__(self, locale: _Optional[str] = ..., version: _Optional[int] = ..., render: bool = ..., extra: _Optional[_Iterable[_Union[_editorial_pb2.Editorial.Extra, str]]] = ...) -> None: ...

class LookupEditorialOutput(_message.Message):
    __slots__ = ("editorial",)
    EDITORIAL_FIELD_NUMBER: _ClassVar[int]
    editorial: _editorial_pb2.Editorial
    def __init__(self, editorial: _Optional[_Union[_editorial_pb2.Editorial, _Mapping]] = ...) -> None: ...

class PreviewEditorialInput(_message.Message):
    __slots__ = ("editorial",)
    EDITORIAL_FIELD_NUMBER: _ClassVar[int]
    editorial: _editorial_pb2.Editorial
    def __init__(self, editorial: _Optional[_Union[_editorial_pb2.Editorial, _Mapping]] = ...) -> None: ...

class PreviewEditorialOutput(_message.Message):
    __slots__ = ("editorial",)
    EDITORIAL_FIELD_NUMBER: _ClassVar[int]
    editorial: _editorial_pb2.Editorial
    def __init__(self, editorial: _Optional[_Union[_editorial_pb2.Editorial, _Mapping]] = ...) -> None: ...

class CreateEditorialInput(_message.Message):
    __slots__ = ("editorial",)
    EDITORIAL_FIELD_NUMBER: _ClassVar[int]
    editorial: _editorial_pb2.Editorial
    def __init__(self, editorial: _Optional[_Union[_editorial_pb2.Editorial, _Mapping]] = ...) -> None: ...

class CreateEditorialOutput(_message.Message):
    __slots__ = ("editorial_id",)
    EDITORIAL_ID_FIELD_NUMBER: _ClassVar[int]
    editorial_id: str
    def __init__(self, editorial_id: _Optional[str] = ...) -> None: ...

class UpdateEditorialInput(_message.Message):
    __slots__ = ("patch", "editorial_id", "editorial")
    PATCH_FIELD_NUMBER: _ClassVar[int]
    EDITORIAL_ID_FIELD_NUMBER: _ClassVar[int]
    EDITORIAL_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[_editorial_pb2.Editorial.Patch]
    editorial_id: str
    editorial: _editorial_pb2.Editorial
    def __init__(self, patch: _Optional[_Iterable[_Union[_editorial_pb2.Editorial.Patch, str]]] = ..., editorial_id: _Optional[str] = ..., editorial: _Optional[_Union[_editorial_pb2.Editorial, _Mapping]] = ...) -> None: ...

class UpdateEditorialOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteEditorialInput(_message.Message):
    __slots__ = ("editorial_id",)
    EDITORIAL_ID_FIELD_NUMBER: _ClassVar[int]
    editorial_id: str
    def __init__(self, editorial_id: _Optional[str] = ...) -> None: ...

class DeleteEditorialOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class TranslateEditorialsInput(_message.Message):
    __slots__ = ("source", "target", "target_automatic", "override_manual")
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    TARGET_AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
    OVERRIDE_MANUAL_FIELD_NUMBER: _ClassVar[int]
    source: str
    target: _containers.RepeatedScalarFieldContainer[str]
    target_automatic: bool
    override_manual: bool
    def __init__(self, source: _Optional[str] = ..., target: _Optional[_Iterable[str]] = ..., target_automatic: bool = ..., override_manual: bool = ...) -> None: ...

class TranslateEditorialsOutput(_message.Message):
    __slots__ = ("job_id",)
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    job_id: str
    def __init__(self, job_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/violation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/violation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/judge/violation.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\"\xad\x04\n\tViolation\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\x06status\x18\x07 \x01(\x0e\x32\x1e.eolymp.judge.Violation.Status\x12*\n\x04type\x18\x08 \x01(\x0e\x32\x1c.eolymp.judge.Violation.Type\x12\x0f\n\x07summary\x18\x03 \x01(\t\x12\x11\n\tautomatic\x18\x04 \x01(\x08\x12\x16\n\x0eparticipant_id\x18\x05 \x01(\t\x12\x15\n\rsubmission_id\x18\x06 \x01(\t\x12\x12\n\ncreated_by\x18\n \x01(\t\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x63onfirmed_by\x18\x0c \x01(\t\x12\x30\n\x0c\x63onfirmed_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aI\n\x05Patch\"@\n\x05\x46ield\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07SUMMARY\x10\x01\x12\n\n\x06STATUS\x10\x02\x12\r\n\tAUTOMATIC\x10\x03\"G\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tCONFIRMED\x10\x02\x12\r\n\tCANCELLED\x10\x03\"E\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\t\n\x05OTHER\x10\x01\x12\x0e\n\nPLAGIARISM\x10\x02\x12\x10\n\x0cGEN_AI_USAGE\x10\x03\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.violation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_VIOLATION']._serialized_start=80
  _globals['_VIOLATION']._serialized_end=637
  _globals['_VIOLATION_PATCH']._serialized_start=420
  _globals['_VIOLATION_PATCH']._serialized_end=493
  _globals['_VIOLATION_PATCH_FIELD']._serialized_start=429
  _globals['_VIOLATION_PATCH_FIELD']._serialized_end=493
  _globals['_VIOLATION_STATUS']._serialized_start=495
  _globals['_VIOLATION_STATUS']._serialized_end=566
  _globals['_VIOLATION_TYPE']._serialized_start=568
  _globals['_VIOLATION_TYPE']._serialized_end=637
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/helpdesk/ticket_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/helpdesk/ticket_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.helpdesk import ticket_pb2 as eolymp_dot_helpdesk_dot_ticket__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/helpdesk/ticket_service.proto\x12\x0f\x65olymp.helpdesk\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/helpdesk/ticket.proto\x1a!eolymp/wellknown/expression.proto\"M\n\x11\x43reateTicketInput\x12\'\n\x06ticket\x18\x01 \x01(\x0b\x32\x17.eolymp.helpdesk.Ticket\x12\x0f\n\x07\x63\x61ptcha\x18\x02 \x01(\t\"\'\n\x12\x43reateTicketOutput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"O\n\x11UpdateTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\'\n\x06ticket\x18\x02 \x01(\x0b\x32\x17.eolymp.helpdesk.Ticket\"\x14\n\x12UpdateTicketOutput\"&\n\x11\x44\x65leteTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteTicketOutput\"8\n\x13\x44\x65scribeTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\"?\n\x14\x44\x65scribeTicketOutput\x12\'\n\x06ticket\x18\x01 \x01(\x0b\x32\x17.eolymp.helpdesk.Ticket\"\xb2\x04\n\x10ListTicketsInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.helpdesk.ListTicketsInput.Filter\x1a\xb4\x03\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x34\n\nuser_email\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06status\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12.\n\x04type\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x39\n\ncreated_at\x18\x07 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x39\n\nupdated_at\x18\x08 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x30\n\x06locale\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"J\n\x11ListTicketsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.helpdesk.Ticket\"8\n\x12\x41pproveTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"\x15\n\x13\x41pproveTicketOutput\"7\n\x11RejectTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"\x14\n\x12RejectTicketOutput\"6\n\x10\x43loseTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"\x13\n\x11\x43loseTicketOutput\"V\n\x0f\x41\x64\x64\x43ommentInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x30\n\x07\x63omment\x18\x02 \x01(\x0b\x32\x1f.eolymp.helpdesk.Ticket.Comment\"&\n\x10\x41\x64\x64\x43ommentOutput\x12\x12\n\ncomment_id\x18\x01 \x01(\t\"m\n\x12UpdateCommentInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x12\n\ncomment_id\x18\x02 \x01(\t\x12\x30\n\x07\x63omment\x18\x03 \x01(\x0b\x32\x1f.eolymp.helpdesk.Ticket.Comment\"\x15\n\x13UpdateCommentOutput\";\n\x12\x44\x65leteCommentInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x12\n\ncomment_id\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteCommentOutput\"T\n\x11ListCommentsInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"S\n\x12ListCommentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.eolymp.helpdesk.Ticket.Comment\"M\n\x14\x44\x65scribeCommentInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x12\n\ncomment_id\x18\x02 \x01(\t\x12\x0e\n\x06render\x18\x03 \x01(\x08\"I\n\x15\x44\x65scribeCommentOutput\x12\x30\n\x07\x63omment\x18\x01 \x01(\x0b\x32\x1f.eolymp.helpdesk.Ticket.Comment\"A\n\x15UploadAttachmentInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"0\n\x16UploadAttachmentOutput\x12\x16\n\x0e\x61ttachment_url\x18\x01 \x01(\t2\xe3\x13\n\rTicketService\x12\x9e\x01\n\x0c\x43reateTicket\x12\".eolymp.helpdesk.CreateTicketInput\x1a#.eolymp.helpdesk.CreateTicketOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x13\"\x11/helpdesk/tickets\x12\xaa\x01\n\x0cUpdateTicket\x12\".eolymp.helpdesk.UpdateTicketInput\x1a#.eolymp.helpdesk.UpdateTicketOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/helpdesk/tickets/{ticket_id}\x12\xaa\x01\n\x0c\x44\x65leteTicket\x12\".eolymp.helpdesk.DeleteTicketInput\x1a#.eolymp.helpdesk.DeleteTicketOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x1f*\x1d/helpdesk/tickets/{ticket_id}\x12\xaf\x01\n\x0e\x44\x65scribeTicket\x12$.eolymp.helpdesk.DescribeTicketInput\x1a%.eolymp.helpdesk.DescribeTicketOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x18\x8a\xe3\n\x14helpdesk:ticket:read\x82\xd3\xe4\x93\x02\x1f\x12\x1d/helpdesk/tickets/{ticket_id}\x12\x9a\x01\n\x0bListTickets\x12!.eolymp.helpdesk.ListTicketsInput\x1a\".eolymp.helpdesk.ListTicketsOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x18\x8a\xe3\n\x14helpdesk:ticket:read\x82\xd3\xe4\x93\x02\x13\x12\x11/helpdesk/tickets\x12\xb5\x01\n\rApproveTicket\x12#.eolymp.helpdesk.ApproveTicketInput\x1a$.eolymp.helpdesk.ApproveTicketOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\'\"%/helpdesk/tickets/{ticket_id}/approve\x12\xb1\x01\n\x0cRejectTicket\x12\".eolymp.helpdesk.RejectTicketInput\x1a#.eolymp.helpdesk.RejectTicketOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02&\"$/helpdesk/tickets/{ticket_id}/reject\x12\xad\x01\n\x0b\x43loseTicket\x12!.eolymp.helpdesk.CloseTicketInput\x1a\".eolymp.helpdesk.CloseTicketOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02%\"#/helpdesk/tickets/{ticket_id}/close\x12\xad\x01\n\nAddComment\x12 .eolymp.helpdesk.AddCommentInput\x1a!.eolymp.helpdesk.AddCommentOutput\"Z\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02(\"&/helpdesk/tickets/{ticket_id}/comments\x12\xc3\x01\n\rUpdateComment\x12#.eolymp.helpdesk.UpdateCommentInput\x1a$.eolymp.helpdesk.UpdateCommentOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x35\x1a\x33/helpdesk/tickets/{ticket_id}/comments/{comment_id}\x12\xc3\x01\n\rDeleteComment\x12#.eolymp.helpdesk.DeleteCommentInput\x1a$.eolymp.helpdesk.DeleteCommentOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x35*3/helpdesk/tickets/{ticket_id}/comments/{comment_id}\x12\xb2\x01\n\x0cListComments\x12\".eolymp.helpdesk.ListCommentsInput\x1a#.eolymp.helpdesk.ListCommentsOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14helpdesk:ticket:read\x82\xd3\xe4\x93\x02(\x12&/helpdesk/tickets/{ticket_id}/comments\x12\xc9\x01\n\x0f\x44\x65scribeComment\x12%.eolymp.helpdesk.DescribeCommentInput\x1a&.eolymp.helpdesk.DescribeCommentOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x35\x12\x33/helpdesk/tickets/{ticket_id}/comments/{comment_id}\x12\xae\x01\n\x10UploadAttachment\x12&.eolymp.helpdesk.UploadAttachmentInput\x1a\'.eolymp.helpdesk.UploadAttachmentOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x17\"\x15/helpdesk/attachmentsB3Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdeskb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.helpdesk.ticket_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdesk'
  _globals['_TICKETSERVICE'].methods_by_name['CreateTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['CreateTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\023\"\021/helpdesk/tickets'
  _globals['_TICKETSERVICE'].methods_by_name['UpdateTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['UpdateTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\037\032\035/helpdesk/tickets/{ticket_id}'
  _globals['_TICKETSERVICE'].methods_by_name['DeleteTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DeleteTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\037*\035/helpdesk/tickets/{ticket_id}'
  _globals['_TICKETSERVICE'].methods_by_name['DescribeTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DescribeTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\030\212\343\n\024helpdesk:ticket:read\202\323\344\223\002\037\022\035/helpdesk/tickets/{ticket_id}'
  _globals['_TICKETSERVICE'].methods_by_name['ListTickets']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ListTickets']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\030\212\343\n\024helpdesk:ticket:read\202\323\344\223\002\023\022\021/helpdesk/tickets'
  _globals['_TICKETSERVICE'].methods_by_name['ApproveTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ApproveTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\'\"%/helpdesk/tickets/{ticket_id}/approve'
  _globals['_TICKETSERVICE'].methods_by_name['RejectTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['RejectTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002&\"$/helpdesk/tickets/{ticket_id}/reject'
  _globals['_TICKETSERVICE'].methods_by_name['CloseTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['CloseTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002%\"#/helpdesk/tickets/{ticket_id}/close'
  _globals['_TICKETSERVICE'].methods_by_name['AddComment']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['AddComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002(\"&/helpdesk/tickets/{ticket_id}/comments'
  _globals['_TICKETSERVICE'].methods_by_name['UpdateComment']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['UpdateComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\0025\0323/helpdesk/tickets/{ticket_id}/comments/{comment_id}'
  _globals['_TICKETSERVICE'].methods_by_name['DeleteComment']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DeleteComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\0025*3/helpdesk/tickets/{ticket_id}/comments/{comment_id}'
  _globals['_TICKETSERVICE'].methods_by_name['ListComments']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ListComments']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024helpdesk:ticket:read\202\323\344\223\002(\022&/helpdesk/tickets/{ticket_id}/comments'
  _globals['_TICKETSERVICE'].methods_by_name['DescribeComment']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DescribeComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\0025\0223/helpdesk/tickets/{ticket_id}/comments/{comment_id}'
  _globals['_TICKETSERVICE'].methods_by_name['UploadAttachment']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['UploadAttachment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\027\"\025/helpdesk/attachments'
  _globals['_CREATETICKETINPUT']._serialized_start=221
  _globals['_CREATETICKETINPUT']._serialized_end=298
  _globals['_CREATETICKETOUTPUT']._serialized_start=300
  _globals['_CREATETICKETOUTPUT']._serialized_end=339
  _globals['_UPDATETICKETINPUT']._serialized_start=341
  _globals['_UPDATETICKETINPUT']._serialized_end=420
  _globals['_UPDATETICKETOUTPUT']._serialized_start=422
  _globals['_UPDATETICKETOUTPUT']._serialized_end=442
  _globals['_DELETETICKETINPUT']._serialized_start=444
  _globals['_DELETETICKETINPUT']._serialized_end=482
  _globals['_DELETETICKETOUTPUT']._serialized_start=484
  _globals['_DELETETICKETOUTPUT']._serialized_end=504
  _globals['_DESCRIBETICKETINPUT']._serialized_start=506
  _globals['_DESCRIBETICKETINPUT']._serialized_end=562
  _globals['_DESCRIBETICKETOUTPUT']._serialized_start=564
  _globals['_DESCRIBETICKETOUTPUT']._serialized_end=627
  _globals['_LISTTICKETSINPUT']._serialized_start=630
  _globals['_LISTTICKETSINPUT']._serialized_end=1192
  _globals['_LISTTICKETSINPUT_FILTER']._serialized_start=756
  _globals['_LISTTICKETSINPUT_FILTER']._serialized_end=1192
  _globals['_LISTTICKETSOUTPUT']._serialized_start=1194
  _globals['_LISTTICKETSOUTPUT']._serialized_end=1268
  _globals['_APPROVETICKETINPUT']._serialized_start=1270
  _globals['_APPROVETICKETINPUT']._serialized_end=1326
  _globals['_APPROVETICKETOUTPUT']._serialized_start=1328
  _globals['_APPROVETICKETOUTPUT']._serialized_end=1349
  _globals['_REJECTTICKETINPUT']._serialized_start=1351
  _globals['_REJECTTICKETINPUT']._serialized_end=1406
  _globals['_REJECTTICKETOUTPUT']._serialized_start=1408
  _globals['_REJECTTICKETOUTPUT']._serialized_end=1428
  _globals['_CLOSETICKETINPUT']._serialized_start=1430
  _globals['_CLOSETICKETINPUT']._serialized_end=1484
  _globals['_CLOSETICKETOUTPUT']._serialized_start=1486
  _globals['_CLOSETICKETOUTPUT']._serialized_end=1505
  _globals['_ADDCOMMENTINPUT']._serialized_start=1507
  _globals['_ADDCOMMENTINPUT']._serialized_end=1593
  _globals['_ADDCOMMENTOUTPUT']._serialized_start=1595
  _globals['_ADDCOMMENTOUTPUT']._serialized_end=1633
  _globals['_UPDATECOMMENTINPUT']._serialized_start=1635
  _globals['_UPDATECOMMENTINPUT']._serialized_end=1744
  _globals['_UPDATECOMMENTOUTPUT']._serialized_start=1746
  _globals['_UPDATECOMMENTOUTPUT']._serialized_end=1767
  _globals['_DELETECOMMENTINPUT']._serialized_start=1769
  _globals['_DELETECOMMENTINPUT']._serialized_end=1828
  _globals['_DELETECOMMENTOUTPUT']._serialized_start=1830
  _globals['_DELETECOMMENTOUTPUT']._serialized_end=1851
  _globals['_LISTCOMMENTSINPUT']._serialized_start=1853
  _globals['_LISTCOMMENTSINPUT']._serialized_end=1937
  _globals['_LISTCOMMENTSOUTPUT']._serialized_start=1939
  _globals['_LISTCOMMENTSOUTPUT']._serialized_end=2022
  _globals['_DESCRIBECOMMENTINPUT']._serialized_start=2024
  _globals['_DESCRIBECOMMENTINPUT']._serialized_end=2101
  _globals['_DESCRIBECOMMENTOUTPUT']._serialized_start=2103
  _globals['_DESCRIBECOMMENTOUTPUT']._serialized_end=2176
  _globals['_UPLOADATTACHMENTINPUT']._serialized_start=2178
  _globals['_UPLOADATTACHMENTINPUT']._serialized_end=2243
  _globals['_UPLOADATTACHMENTOUTPUT']._serialized_start=2245
  _globals['_UPLOADATTACHMENTOUTPUT']._serialized_end=2293
  _globals['_TICKETSERVICE']._serialized_start=2296
  _globals['_TICKETSERVICE']._serialized_end=4827
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class EmailType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_TYPE: _ClassVar[EmailType]
    ACCOUNT: _ClassVar[EmailType]
    NEWSLETTER: _ClassVar[EmailType]
    UPDATES: _ClassVar[EmailType]
    COMMERCIAL: _ClassVar[EmailType]
    OTHER: _ClassVar[EmailType]
UNKNOWN_TYPE: EmailType
ACCOUNT: EmailType
NEWSLETTER: EmailType
UPDATES: EmailType
COMMERCIAL: EmailType
OTHER: EmailType
